#!/bin/sh
#
#	Copyright (c)2001 Grumbler
#
# $Id: trafd.sh,v 1.4 2004/04/22 19:03:23 stas_degteff Exp $
#
#
# if $1=='start': start of the network traffic collector
# if $1=='stop' : dump all records to /var/tmp/trafd.$iface
#		and shutdown network traffic collector ('kill')
#
# You can set following variables in the /etc/rc.conf:
# trafd_ifaces   - interfaces list
# trafd_flags    - common trafd options
# trafd_<iface>  - (where <iface> should be relaces with the interface name)
#                  trafd options and parameters for the interface <iface>
#                  here you may set up the filter expression
#

OS=`uname`

if [ -f /etc/rc.conf ] ; then
. /etc/rc.conf
fi

if [ -f /etc/trafd/trafd.conf ] ; then
. /etc/trafd/trafd.conf
fi

if [ "x$OS" = 'xLinux' ] ; then
   PROGRAM='/usr/sbin/trafd'
else
   PROGRAM='/usr/local/sbin/trafd'
fi

# Interfaces for traffic accounting

if [ "${trafd_ifaces}" ] ; then
	ifaces="${trafd_ifaces}"
elif [ "${IFF_LISTEN}" ] ; then
	ifaces="${IFF_LISTEN}"
else
#	iface="`/sbin/ifconfig -lu | /usr/bin/sed s/\ .*//`"  # 1st iface in list
	if [ "x$OS" = 'xLinux' ] ; then
	   ifaces="`/sbin/ifconfig | egrep '^[a-z]{2,3}[0-9]+ .*' | cut -d ' ' -f1 | sed s/lo0//`"
	else
	   # all ifaces except loopback (lo0)
	   ifaces="`/sbin/ifconfig -lu | /usr/bin/sed s/lo0//`"
	fi
fi

if [ ! "${ifaces}" ] ; then
	/bin/echo "Not an interface for listen!"
	/bin/echo `/bin/date +"%b %e %H:%M:%S"` `/bin/hostname -s` trafd.sh: Not an interface for listen!
	exit -1
fi


WHERE_PID=/var/run/trafd.
LOG_FILE=/var/log/trafd.log

case $1 in
start)
	for iface in $ifaces; do
	  if [ trafd_${iface}_opts ] ; then
	    op=\$"trafd_${iface}"
	    OPTS=`eval echo $op`
	  elif [ trafd_flags ] ; then
	  else
	    OPTS='-pr'
	  fi
	  ${PROGRAM} -i ${iface} ${trafd_flags} ${OPTS} && /bin/echo " ${PROGRAM} -i ${iface} ${trafd_flags} ${OPTS} "
	  if [ $? = 0 ]; then
	    /bin/echo `/bin/date +"%b %e %H:%M:%S"` `/bin/hostname -s` trafd.sh: '('$iface')' started >> $LOG_FILE
	  fi
	done
        ;;
stop)
	for iface in $ifaces; do
	  PID_FILE=$WHERE_PID$iface
	  if [ -f $PID_FILE ]; then
	    PID="`cat $PID_FILE`"
	    /bin/kill -QUIT ${PID}
	    if [ $? = 0 ]; then
		/bin/echo `/bin/date +"%b %e %H:%M:%S"` `/bin/hostname -s` trafd.sh: '('$iface')' signaling to shutdown >> $LOG_FILE
	    fi
	  else
	    if [ ! -d $LOG_FILE -a -w $LOG_FILE ]; then
		/bin/echo "`/bin/date +"%b %e %H:%M:%S"` `/bin/hostname -s` trafd.sh: \(stop\) error: $PID_FILE not found" | /usr/bin/tee -a $LOG_FILE
	    else
		/bin/echo "`/bin/date +"%b %e %H:%M:%S"` `/bin/hostname -s` trafd.sh: \(stop\) warning: $PID_FILE not found"
	    fi
	  fi
	done
        ;;
*)
        /bin/echo "Usage: trafd.sh {start|stop}" >&2
        exit 64
        ;;
esac

exit 0

